@@ -1,6 +1,6 @@
 /* automatic.{cc,hh} -- code for automatic mode and interfacing with kpathsea
  *
- * Copyright (c) 2003-2018 Eddie Kohler
+ * Copyright (c) 2003-2019 Eddie Kohler
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -39,7 +39,9 @@
 #include <algorithm>
 
 #ifdef WIN32
-# define mkdir(dir, access) mkdir(dir)
+# include <io.h>
+# include <direct.h>
+# define mkdir(dir, access) _mkdir(dir)
 # define COPY_CMD "copy"
 # define CMD_SEP "&"
 #else
@@ -124,7 +126,16 @@ look_for_writable_texdir(const char *path_variable, bool create)
 static void
 find_writable_texdir(ErrorHandler *errh, const char *)
 {
-    look_for_writable_texdir("$TEXMFVAR", true);
+    // Check if TEXMFVAR is writable.
+    // Some distributions like W32TeX do not have TEXMFVAR defined,
+    // in which case we check TEXMFLOCAL.
+    char *p = kpsei_var_value("TEXMFVAR");
+    if (p == NULL)
+        look_for_writable_texdir("$TEXMFLOCAL", true);
+    else {
+        free (p);
+        look_for_writable_texdir("$TEXMFVAR", true);
+    }
     if (!writable_texdir)
         look_for_writable_texdir("$VARTEXMF", false);
     if (!writable_texdir)
@@ -313,7 +324,7 @@ update_odir(int o, String file, ErrorHandler *errh)
     String ls_r = writable_texdir + "ls-R";
     bool success = false;
     if (access(ls_r.c_str(), R_OK) >= 0) // make sure it already exists
-        if (FILE *f = fopen(ls_r.c_str(), "a")) {
+        if (FILE *f = fopen(ls_r.c_str(), "ab")) {
             fprintf(f, "./%s:\n%s\n", directory.c_str(), file.c_str());
             success = true;
             fclose(f);
@@ -323,7 +334,11 @@ update_odir(int o, String file, ErrorHandler *errh)
     if (!success && writable_texdir.find_left('\'') < 0 && directory.find_left('\'') < 0 && file.find_left('\'') < 0) {
         // look for mktexupd script
         if (!mktexupd_tried) {
+#ifdef _WIN32
+            mktexupd = "mktexupd.exe";
+#else
             mktexupd = kpsei_string(kpsei_find_file("mktexupd", KPSEI_FMT_WEB2C));
+#endif
             mktexupd_tried = true;
         }
 
@@ -677,7 +692,7 @@ update_autofont_map(const String &fontname, String mapline, ErrorHandler *errh)
 #endif
             {
                 fclose(f);
-                f = fopen(map_file.c_str(), "w");
+                f = fopen(map_file.c_str(), "wb");
                 fd = fileno(f);
             }
 
@@ -693,12 +708,14 @@ update_autofont_map(const String &fontname, String mapline, ErrorHandler *errh)
 
 #if HAVE_KPATHSEA && !WIN32
         // run 'updmap' if present
+        String updmap_prog = output_flags & G_UPDMAP_USER ? "updmap-user" : "updmap-sys";
         String updmap_dir, updmap_file;
         if (automatic && (output_flags & G_UPDMAP))
             updmap_dir = getodir(O_MAP_PARENT, errh);
-        if (updmap_dir && (updmap_file = updmap_dir + "/updmap")
+        if (updmap_dir
+            && (updmap_file = updmap_dir + "/" + updmap_prog)
             && access(updmap_file.c_str(), X_OK) >= 0) {
-            // want to run 'updmap' from its directory, can't use system()
+            // want to run `updmap` from its directory, can't use system()
             if (verbose)
                 errh->message("running %s", updmap_file.c_str());
 
@@ -709,7 +726,9 @@ update_autofont_map(const String &fontname, String mapline, ErrorHandler *errh)
                 // change to updmap directory, run it
                 if (chdir(updmap_dir.c_str()) < 0)
                     errh->fatal("%s: %s during chdir", updmap_dir.c_str(), strerror(errno));
-                if (execl("./updmap", updmap_file.c_str(), (const char*) 0) < 0)
+                if (execl(output_flags & G_UPDMAP_USER ? "./updmap-user" : "./updmap-sys",
+                          updmap_file.c_str(),
+                          (const char*) 0) < 0)
                     errh->fatal("%s: %s during exec", updmap_file.c_str(), strerror(errno));
                 exit(1);        // should never get here
             }
@@ -742,8 +761,8 @@ update_autofont_map(const String &fontname, String mapline, ErrorHandler *errh)
             if (slash >= 0)
                 filename = filename.substring(slash + 1);
             String redirect = verbose ? " 1>&2" : " >" DEV_NULL " 2>&1";
-            String command = "updmap --nomkmap --enable Map " + shell_quote(filename) + redirect
-                + CMD_SEP " updmap" + redirect;
+            String command = updmap_prog + " --nomkmap --enable Map " + shell_quote(filename) + redirect
+                + CMD_SEP " " + updmap_prog + redirect;
             int retval = mysystem(command.c_str(), errh);
             if (retval == 127)
                 errh->warning("could not run %<%s%>", command.c_str());
