@@ -1,6 +1,6 @@
 /* t1lint.cc -- driver for checking Type 1 fonts for validity
  *
- * Copyright (c) 1999-2013 Eddie Kohler
+ * Copyright (c) 1999-2023 Eddie Kohler
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -38,9 +38,9 @@
 
 using namespace Efont;
 
-#define VERSION_OPT	301
-#define HELP_OPT	302
-#define QUIET_OPT	303
+#define VERSION_OPT     301
+#define HELP_OPT        302
+#define QUIET_OPT       303
 
 const Clp_Option options[] = {
   { "help", 'h', HELP_OPT, 0, 0 },
@@ -60,9 +60,10 @@ usage_error(ErrorHandler *errh, const char *error_message, ...)
   if (!error_message)
     errh->message("Usage: %s [OPTION]... FONT", program_name);
   else
-    errh->vxmessage(ErrorHandler::e_error, error_message, val);
+    errh->xmessage(ErrorHandler::e_error, error_message, val);
   errh->message("Type %s --help for more information.", program_name);
   exit(1);
+  va_end(val);
 }
 
 void
@@ -94,34 +95,34 @@ Report bugs to <ekohler@gmail.com>.\n", program_name);
 
 static bool
 get_num_array(Type1Font *font, int dictionary, const char *name,
-	      Vector<double> &v, ErrorHandler *errh, bool mandatory = false)
+              Vector<double> &v, ErrorHandler *errh, bool mandatory = false)
 {
     if (Type1Definition *d = font->dict(dictionary, name)) {
-	if (d->value_numvec(v))
-	    return true;
-	errh->error("%s not an array of numbers", name);
-	v.clear();
+        if (d->value_numvec(v))
+            return true;
+        errh->error("%s not an array of numbers", name);
+        v.clear();
     } else if (mandatory)
-	errh->error("%s not defined", name);
+        errh->error("%s not defined", name);
     return false;
 }
 
 static bool
 get_integer(Type1Font *font, int dictionary, const char *name,
-	    int &v, ErrorHandler *errh, bool mandatory = false)
+            int &v, ErrorHandler *errh, bool mandatory = false)
 {
     Type1Definition *d = font->dict(dictionary, name);
     double scratch;
     if (d && d->value_int(v))
-	return true;
+        return true;
     else if (d && d->value_num(scratch)) {
-	errh->warning("%s not an integer", name);
-	v = (int)scratch;
-	return true;
+        errh->warning("%s not an integer", name);
+        v = (int)scratch;
+        return true;
     } else if (d)
-	errh->error("%s not a number", name);
+        errh->error("%s not a number", name);
     else if (mandatory)
-	errh->error("%s not defined", name);
+        errh->error("%s not defined", name);
     return false;
 }
 
@@ -129,7 +130,7 @@ get_integer(Type1Font *font, int dictionary, const char *name,
 
 static void
 check_blue_array(Vector<double> &blues, const char *name, double BlueScale,
-		 ErrorHandler *errh)
+                 ErrorHandler *errh)
 {
   if (blues.size() % 2 != 0) {
     errh->error("%s has an odd number of entries", name);
@@ -147,27 +148,27 @@ check_blue_array(Vector<double> &blues, const char *name, double BlueScale,
     if (blues[i] > blues[i+1])
       errh->error("%s zone %d in the wrong order", name, i/2);
     else if (blues[i+1] - blues[i] >= max_diff)
-	errh->error("%s zone %d too large in relation to BlueScale (size %g, max %g [%g])", name, i/2, blues[i+1] - blues[i], max_diff, BlueScale);
+        errh->error("%s zone %d too large in relation to BlueScale (size %g, max %g [%g])", name, i/2, blues[i+1] - blues[i], max_diff, BlueScale);
   }
 }
 
 static void
 check_blue_overlap(Vector<double> &bl1, const char *name1,
-		   Vector<double> &bl2, const char *name2, int BlueFuzz,
-		   ErrorHandler *errh)
+                   Vector<double> &bl2, const char *name2, int BlueFuzz,
+                   ErrorHandler *errh)
 {
   int min_fuzz = 2*BlueFuzz + 1;
   for (int i = 2; i < bl1.size(); i += 2) {
     int thresh = (&bl1 == &bl2 ? i : bl2.size());
     for (int j = 0; j < thresh; j += 2) {
       if ((bl2[j] >= bl1[i] && bl2[j] <= bl1[i+1])
-	  || (bl2[j+1] >= bl1[i] && bl2[j+1] <= bl1[i+1]))
-	errh->error("%s zone %d and %s zone %d overlap",
-		    name1, i/2, name2, j/2);
+          || (bl2[j+1] >= bl1[i] && bl2[j+1] <= bl1[i+1]))
+        errh->error("%s zone %d and %s zone %d overlap",
+                    name1, i/2, name2, j/2);
       else if ((bl2[j] >= bl1[i+1] && bl2[j] < bl1[i+1]+min_fuzz)
-	       || (bl2[j+1] <= bl1[i] && bl2[j+1]+min_fuzz > bl1[i]))
-	errh->error("%s zone %d and %s zone %d overlap within BlueFuzz",
-		    name1, i/2, name2, j/2);
+               || (bl2[j+1] <= bl1[i] && bl2[j+1]+min_fuzz > bl1[i]))
+        errh->error("%s zone %d and %s zone %d overlap within BlueFuzz",
+                    name1, i/2, name2, j/2);
     }
   }
 }
@@ -187,7 +188,7 @@ check_blues(Type1Font *font, ErrorHandler *errh)
       errh->error("BlueScale less than or equal to 0");
     else {
       if (BlueScale > 0.5)
-	errh->error("suspiciously large BlueScale (%g)", BlueScale);
+        errh->error("suspiciously large BlueScale (%g)", BlueScale);
       ok = true;
     }
   }
@@ -249,7 +250,7 @@ check_blues(Type1Font *font, ErrorHandler *errh)
 
 void
 check_stem_snap(Vector<double> &stem_snap, double main, bool is_v,
-		ErrorHandler *errh)
+                ErrorHandler *errh)
 {
   const char *name = (is_v ? "V" : "H");
   if (stem_snap.size() > 12)
@@ -294,7 +295,7 @@ check_stems(Type1Font *font, ErrorHandler *errh)
 
 static void
 do_file(const char *filename, PsresDatabase *psres, ErrorHandler *errh,
-	ErrorHandler *err_errh)
+        ErrorHandler *err_errh)
 {
   FILE *f;
   if (strcmp(filename, "-") == 0) {
@@ -333,25 +334,25 @@ do_file(const char *filename, PsresDatabase *psres, ErrorHandler *errh,
     // check UniqueID values
     int UniqueID = -1, UniqueID2 = -1;
     if (get_integer(font, Type1Font::dF, "UniqueID", UniqueID, errh)
-	&& (UniqueID < 0 || UniqueID > 0xFFFFFF))
-	cerrh.error("UniqueID not in the range 0-16777215");
+        && (UniqueID < 0 || UniqueID > 0xFFFFFF))
+        cerrh.error("UniqueID not in the range 0-16777215");
     if (get_integer(font, Type1Font::dP, "UniqueID", UniqueID2, errh)
-	&& (UniqueID2 < 0 || UniqueID2 > 0xFFFFFF))
-	cerrh.error("Private UniqueID not in the range 0-16777215");
+        && (UniqueID2 < 0 || UniqueID2 > 0xFFFFFF))
+        cerrh.error("Private UniqueID not in the range 0-16777215");
     if (UniqueID >= 0 && UniqueID2 >= 0 && UniqueID != UniqueID2)
-	cerrh.error("Private UniqueID does not equal font UniqueID");
+        cerrh.error("Private UniqueID does not equal font UniqueID");
 
     // check XUID values
     Vector<double> XUID;
     if (get_num_array(font, Type1Font::dF, "XUID", XUID, errh)) {
-	if (XUID.size() == 0)
-	    cerrh.error("empty XUID");
-	for (int i = 0; i < XUID.size(); i++) {
-	    if (floor(XUID[i]) != XUID[i] || XUID[i] < 0 || XUID[i] > 0xFFFFFF) {
-		cerrh.error("element of XUID not an integer in the range 0-16777215");
-		break;
-	    }
-	}
+        if (XUID.size() == 0)
+            cerrh.error("empty XUID");
+        for (int i = 0; i < XUID.size(); i++) {
+            if (floor(XUID[i]) != XUID[i] || XUID[i] < 0 || XUID[i] > 0xFFFFFF) {
+                cerrh.error("element of XUID not an integer in the range 0-16777215");
+                break;
+            }
+        }
     }
 
     check_blues(font, &cerrh);
@@ -360,24 +361,24 @@ do_file(const char *filename, PsresDatabase *psres, ErrorHandler *errh,
     MultipleMasterSpace *mmspace = font->create_mmspace(&cerrh);
     Vector<double> weight_vector;
     if (mmspace)
-	weight_vector = mmspace->default_weight_vector();
+        weight_vector = mmspace->default_weight_vector();
     int gc = font->nglyphs();
     CharstringChecker cc(weight_vector);
 
     for (int i = 0; i < gc; i++) {
       ContextErrorHandler derrh
-	  (&cerrh, "While interpreting %<%s%>:", font->glyph_name(i).c_str());
+          (&cerrh, "While interpreting %<%s%>:", font->glyph_name(i).c_str());
       cc.check(font->glyph_context(i), &derrh);
     }
 
     int ns = font->nsubrs();
     CharstringSubrChecker csc(weight_vector);
     for (int i = 0; i < ns; ++i)
-	if (Type1Charstring *cs = font->subr(i)) {
-	    ContextErrorHandler derrh(&cerrh, "While interpreting subr %d:", i);
-	    CharstringContext cctx(font, cs);
-	    csc.check(cctx, &derrh);
-	}
+        if (Type1Charstring *cs = font->subr(i)) {
+            ContextErrorHandler derrh(&cerrh, "While interpreting subr %d:", i);
+            CharstringContext cctx(font, cs);
+            csc.check(cctx, &derrh);
+        }
   }
 
   delete font;
@@ -405,14 +406,14 @@ main(int argc, char *argv[])
 
      case QUIET_OPT:
        if (clp->negated)
-	   errh = out_errh;
+           errh = out_errh;
        else
-	   errh = new SilentErrorHandler;
+           errh = new SilentErrorHandler;
        break;
 
      case VERSION_OPT:
       printf("t1lint (LCDF typetools) %s\n", VERSION);
-      printf("Copyright (C) 1999-2013 Eddie Kohler\n\
+      printf("Copyright (C) 1999-2023 Eddie Kohler\n\
 This is free software; see the source for copying conditions.\n\
 There is NO warranty, not even for merchantability or fitness for a\n\
 particular purpose.\n");
